@@ -24,7 +24,8 @@
 */
 var NAVTREE =
 [
-  [ "Doxygen", "index.html", [
+  [ "Manual", "index.html", [
+    [ "Doxygen", "index.html", null ],
     [ "Installation", "install.html", [
       [ "Compiling from source on UNIX", "install.html#install_src_unix", null ],
       [ "Installing the binaries on UNIX", "install.html#install_bin_unix", null ],
@@ -57,6 +58,13 @@ var NAVTREE =
       ] ],
       [ "Anatomy of a comment block", "docblocks.html#docstructure", null ]
     ] ],
+    [ "Additional Documentation", "additional.html", [
+      [ "Custom Pages", "additional.html#custom_pages", null ],
+      [ "Scaling Up", "additional.html#scaling", [
+        [ "Automatically Adding Files", "additional.html#automatically_adding_files", null ],
+        [ "Side Panel Treeview", "additional.html#treeview", null ]
+      ] ]
+    ] ],
     [ "Markdown support", "markdown.html", [
       [ "Standard Markdown", "markdown.html#markdown_std", [
         [ "Paragraphs", "markdown.html#md_para", null ],
@@ -113,21 +121,7 @@ var NAVTREE =
       [ "typedefs", "autolink.html#resolving", null ]
     ] ],
     [ "Output Formats", "output.html", null ],
-    [ "Searching", "searching.html", [
-      [ "External Indexing and Searching", "extsearch.html", [
-        [ "Introduction", "extsearch.html#extsearch_intro", null ],
-        [ "Configuring", "extsearch.html#extsearch_config", [
-          [ "Single project index", "extsearch.html#extsearch_single", null ],
-          [ "Multi project index", "extsearch.html#extsearch_multi", null ]
-        ] ],
-        [ "Updating the index", "extsearch.html#extsearch_update", null ],
-        [ "Programming interface", "extsearch.html#extsearch_api", [
-          [ "Indexer input format", "extsearch.html#extsearch_api_index", null ],
-          [ "Search URL format", "extsearch.html#extsearch_api_search_in", null ],
-          [ "Search results format", "extsearch.html#extsearch_api_search_out", null ]
-        ] ]
-      ] ]
-    ] ],
+    [ "Searching", "searching.html", "searching" ],
     [ "Customizing the output", "customize.html", [
       [ "Minor Tweaks", "customize.html#minor_tweaks", [
         [ "Overall Color", "customize.html#minor_tweaks_colors", null ],
@@ -156,9 +150,9 @@ var NAVTREE =
       [ "The overall HTML output looks different, while I only wanted to use my own html header file", "faq.html#faq_html_header", null ],
       [ "Why does doxygen use Qt?", "faq.html#faq_use_qt", null ],
       [ "How can I exclude all test directories from my directory tree?", "faq.html#faq_excl_dir", null ],
-      [ "Doxygen automatically generates a link to the class MyClass somewhere in the running text.  How do I prevent that at a certain place?", "faq.html#faq_class", null ],
+      [ "Doxygen automatically generates a link to the class MyClass somewhere in the running text....", "faq.html#faq_class", null ],
       [ "My favorite programming language is X. Can I still use doxygen?", "faq.html#faq_pgm_X", null ],
-      [ "Help! I get the cryptic message \"input buffer overflow, can't enlarge buffer because scanner uses REJECT\"", "faq.html#faq_lex", null ],
+      [ "Help! I get the cryptic message \"input buffer overflow, can't enlarge buffer because scanner uses REJ...", "faq.html#faq_lex", null ],
       [ "When running make in the latex directory I get \"TeX capacity exceeded\". Now what?", "faq.html#faq_latex", null ],
       [ "Why are dependencies via STL classes not shown in the dot graphs?", "faq.html#faq_stl", null ],
       [ "I have problems getting the search engine to work with PHP5 and/or windows", "faq.html#faq_search", null ],
@@ -224,6 +218,8 @@ var NAVTREE =
       [ "\\hiderefby", "commands.html#cmdhiderefby", null ],
       [ "\\showrefs", "commands.html#cmdshowrefs", null ],
       [ "\\hiderefs", "commands.html#cmdhiderefs", null ],
+      [ "\\showinlinesource", "commands.html#cmdshowinlinesource", null ],
+      [ "\\hideinlinesource", "commands.html#cmdhideinlinesource", null ],
       [ "\\includegraph", "commands.html#cmdincludegraph", null ],
       [ "\\hideincludegraph", "commands.html#cmdhideincludegraph", null ],
       [ "\\includedbygraph", "commands.html#cmdincludedbygraph", null ],
@@ -232,6 +228,8 @@ var NAVTREE =
       [ "\\hidedirectorygraph", "commands.html#cmdhidedirectorygraph", null ],
       [ "\\collaborationgraph", "commands.html#cmdcollaborationgraph", null ],
       [ "\\hidecollaborationgraph", "commands.html#cmdhidecollaborationgraph", null ],
+      [ "\\inheritancegraph['{option}']", "commands.html#cmdinheritancegraph", null ],
+      [ "\\hideinheritancegraph", "commands.html#cmdhideinheritancegraph", null ],
       [ "\\groupgraph", "commands.html#cmdgroupgraph", null ],
       [ "\\hidegroupgraph", "commands.html#cmdhidegroupgraph", null ],
       [ "\\qualifier <label> | \"(text)\"", "commands.html#cmdqualifier", null ],
@@ -450,6 +448,9 @@ var NAVTREE =
     ] ],
     [ "Doxygen's Internals", "arch.html", null ],
     [ "Changelog", "changelog.html", [
+      [ "1.10 Series", "changelog.html#log_1_10", [
+        [ "Release 1.10.0", "changelog.html#log_1_10_0", null ]
+      ] ],
       [ "1.9 Series", "changelog.html#log_1_9", [
         [ "Release 1.9.8", "changelog.html#log_1_9_8", null ],
         [ "Release 1.9.7", "changelog.html#log_1_9_7", null ],
@@ -501,8 +502,8 @@ var NAVTREE =
 
 var NAVTREEINDEX =
 [
-"arch.html",
-"commands.html#cmdthrows"
+"additional.html",
+"commands.html#cmdsnippetdoc"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
